/**
 * @file
 * SimpleMDE implementation of {@link Drupal.editors} API.
 */

(function(Drupal, editormd) {

  'use strict';

  /**
   * @namespace
   */
  Drupal.editors.editor_md = {

    /**
     * Editor attach callback.
     *
     * @param {HTMLElement} element
     *   The element to attach the editor to.
     * @param {string} format
     *   The text format for the editor.
     *
     * @return {bool}
     *   Whether the editor was successfully attached.
     */
    attach: function(element, format) {
      var textarea = document.getElementById(element.id);
      var textarea_wapper = textarea.parentNode;
      textarea_wapper.id = element.id + '-wrapper';

      if (!textarea_wapper.classList.contains('editor_md-processed')) {
        textarea_wapper.classList.add('editor_md-processed');
        var settings = format.editorSettings;
        settings.element = textarea_wapper;
        settings.forceSync = true;
        var editor = editormd(textarea_wapper.id, {
          width: "100%",
          height: 440,
          path: '../plugin/editor.md/lib/',
          theme: "default",
          previewTheme: "default",
          editorTheme: "base16-light",
          // codeFold: true,
          // syncScrolling : false,
          saveHTMLToTextarea : settings.saveHTMLToTextarea ,    // 保存 HTML 到 Textarea
          // searchReplace : true,
          // watch : false,                // 关闭实时预览
          // htmlDecode : "style,script,iframe|on*",            // 开启 HTML 标签解析，为了安全性，默认不开启
          // toolbar  : false,             //关闭工具栏
          // previewCodeHighlight : false, // 关闭预览 HTML 的代码块高亮，默认开启
          // emoji: true,
          // taskList : true,
          // tocm            : true,         // Using [TOCM]
          // tex : true,                   // 开启科学公式TeX语言支持，默认关闭
          // flowChart : true,             // 开启流程图支持，默认关闭
          // sequenceDiagram : true,       // 开启时序/序列图支持，默认关闭,
          // dialogLockScreen : false,   // 设置弹出层对话框不锁屏，全局通用，默认为true
          // dialogShowMask : false,     // 设置弹出层对话框显示透明遮罩层，全局通用，默认为true
          // dialogDraggable : false,    // 设置弹出层对话框不可拖动，全局通用，默认为true
          // dialogMaskOpacity : 0.4,    // 设置透明遮罩层的透明度，全局通用，默认值为0.1
          // dialogMaskBgColor : "#000", // 设置透明遮罩层的背景颜色，全局通用，默认为#fff
          // imageUpload: settings.imageUpload,
          // imageFormats: ["jpg", "jpeg", "gif", "png", "bmp", "webp"],
          // imageUploadURL: 'public://' + settings.imageUploadURL,
        });
        return !!editor;
      }
    },
    // editormd
    /**
     * Editor detach callback.
     *
     * @param {HTMLElement} element
     *   The element to detach the editor from.
     * @param {string} format
     *   The text format used for the editor.
     * @param {string} trigger
     *   The event trigger for the detach.
     *
     * @return {bool}
     *   Whether the editor was successfully detached.
     */
    detach: function(element, format, trigger) {

    },

    /**
     * Reacts on a change in the editor element.
     *
     * @param {HTMLElement} element
     *   The element where the change occurred.
     * @param {function} callback
     *   Callback called with the value of the editor.
     */
    onChange: function(element, callback) {
      callback();
    }

  };

})(Drupal, editormd);
